==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/scripts/kn.php <==
<?php

return [
    'Names' => [
        'Arab' => 'ಅರೇಬಿಕ್',
        'Armi' => 'ಇಂಪೀರಿಯಲ್ ಅರೆಮಾಯಿಕ್',
        'Armn' => 'ಅರ್ಮೇನಿಯನ್',
        'Avst' => 'ಅವೆಸ್ತಾನ್',
        'Bali' => 'ಬಾಲಿನೀಸ್',
        'Batk' => 'ಬಾಟಕ್',
        'Beng' => 'ಬೆಂಗಾಲಿ',
        'Blis' => 'ಬ್ಲಿಸ್‌ಸಿಂಬಲ್ಸ್',
        'Bopo' => 'ಬೋಪೊಮೋಫೋ',
        'Brah' => 'ಬ್ರಾಹ್ಮಿ',
        'Brai' => 'ಬ್ರೈಲ್',
        'Bugi' => 'ಬಗಿನೀಸ್',
        'Buhd' => 'ಬುಹಿದ್',
        'Cakm' => 'ಕಾಕಂ',
        'Cans' => 'ಯುನಿಟೆಡ್ ಕೆನೆಡಿಯನ್ ಅಬೊರಿಜಿನಲ್ ಸಿಲ್ಯಾಬಿಕ್ಸ್',
        'Cari' => 'ಕರೇನ್',
        'Cham' => 'ಚಾಮ್',
        'Cher' => 'ಚೆರೋಕೀ',
        'Cirt' => 'ಸಿರ್ಥ್',
        'Copt' => 'ಕಾಪ್ಟಿಕ್',
        'Cprt' => 'ಸಿಪ್ರಿಯಾಟ್',
        'Cyrl' => 'ಸಿರಿಲಿಕ್',
        'Cyrs' => 'ಪ್ರಾಚೀನ ಚರ್ಚ್ ಸ್ಲೋವಾನಿಕ್ ಸಿರಿಲಿಕ್',
        'Deva' => 'ದೇವನಾಗರಿ',
        'Dsrt' => 'ಡಸರ್ಟ್',
        'Egyd' => 'ಈಜಿಪ್ಟಿಯನ್ ಡೆಮೋಟಿಕ್',
        'Egyh' => 'ಈಜಿಪ್ಟಿಯನ್ ಹಯಾರಿಟಿಕ್',
        'Egyp' => 'ಈಜಿಪ್ಟಿಯನ್ ಹೀರೋಗ್ಲಿಫ್ಸ್',
        'Ethi' => 'ಇಥಿಯೋಪಿಕ್',
        'Geok' => 'ಜಾರ್ಜಿಯನ್ ಖುಸ್ತುರಿ',
        'Geor' => 'ಜಾರ್ಜಿಯನ್',
        'Glag' => 'ಗ್ಲಾಗೋಲಿಟಿಕ್',
        'Goth' => 'ಗೋತಿಕ್',
        'Grek' => 'ಗ್ರೀಕ್',
        'Gujr' => 'ಗುಜರಾತಿ',
        'Guru' => 'ಗುರ್ಮುಖಿ',
        'Hanb' => 'ಬೋಪೋಮೊಫೋ ಜೊತೆಗೆ ಹಾನ್',
        'Hang' => 'ಹ್ಯಾಂಗುಲ್',
        'Hani' => 'ಹಾನ್',
        'Hano' => 'ಹನೂನೂ',
        'Hans' => 'ಸರಳೀಕೃತ',
        'Hant' => 'ಸಾಂಪ್ರದಾಯಿಕ',
        'Hebr' => 'ಹೀಬ್ರೂ',
        'Hira' => 'ಹಿರಾಗನ',
        'Hmng' => 'ಪಹವ್ ಹ್ಮೋಂಗ್',
        'Hrkt' => 'ಜಪಾನೀಸ್ ಸಿಲಬರೀಸ್',
        'Hung' => 'ಪ್ರಾಚೀನ ಹಂಗೇರಿಯನ್',
        'Inds' => 'ಸಿಂಧೂ',
        'Ital' => 'ಪ್ರಾಚೀನ್ ಇಟಾಲಿಕ್',
        'Jamo' => 'ಜಮೋ',
        'Java' => 'ಜಾವನೀಸ್',
        'Jpan' => 'ಜಾಪನೀಸ್',
        'Kali' => 'ಕೆಯಾ ಲಿ',
        'Kana' => 'ಕಟಕಾನಾ',
        'Khar' => 'ಖರೋಶ್ತಿ',
        'Khmr' => 'ಖಮೇರ್',
        'Knda' => 'ಕನ್ನಡ',
        'Kore' => 'ಕೊರಿಯನ್',
        'Kthi' => 'ಕೈಥಿ',
        'Lana' => 'ಲಾನಾ',
        'Laoo' => 'ಲಾವೋ',
        'Latf' => 'ಫ್ರಾಕ್ತರ್ ಲ್ಯಾಟಿನ್',
        'Latg' => 'ಗೇಲಿಕ್ ಲ್ಯಾಟಿನ್',
        'Latn' => 'ಲ್ಯಾಟಿನ್',
        'Lepc' => 'ಲೆಪ್ಚಾ',
        'Limb' => 'ಲಿಂಬು',
        'Lina' => 'ಲೀನಯರ್ ಎ',
        'Linb' => 'ಲೀನಯರ್ ಬಿ',
        'Lyci' => 'ಲೈಸಿಯನ್',
        'Lydi' => 'ಲಿಡಿಯನ್',
        'Mand' => 'ಮಂಡೇಯನ್',
        'Mani' => 'ಮನಿಚೈಯನ್',
        'Maya' => 'ಮಯಾನ್ ಹೀರೋಗ್ಲಿಫ್ಸ್',
        'Mero' => 'ಮೆರೊಯಿಟಿಕ್',
        'Mlym' => 'ಮಲಯಾಳಂ',
        'Mong' => 'ಮಂಗೋಲಿಯನ್',
        'Moon' => 'ಮೂನ್',
        'Mtei' => 'ಮೈತಿ ಮಯೆಕ್',
        'Mymr' => 'ಮ್ಯಾನ್ಮಾರ್',
        'Nkoo' => 'ಎನ್‍ಕೋ',
        'Ogam' => 'ಓಘಮ್',
        'Olck' => 'ಓಲ್ ಚಿಕಿ',
        'Orkh' => 'ಓರ್ಖೋನ್',
        'Orya' => 'ಒಡಿಯಾ',
        'Osma' => 'ಓಸ್ಮಾನ್ಯಾ',
        'Perm' => 'ಪ್ರಾಚೀನ ಪೆರ್ಮಿಕ್',
        'Phag' => 'ಫಾಗ್ಸ್-ಪಾ',
        'Phli' => 'ಇನ್ಸ್‌ಕ್ರಿಪ್ಶನಲ್ ಪಾಹ್ಲವಿ',
        'Phlp' => 'ಸಾಲ್ಟರ್ ಪಾಹ್ಲವಿ',
        'Phlv' => 'ಬುಕ್ ಪಾಹ್ಲವಿ',
        'Phnx' => 'ಫೀನಿಶಿಯನ್',
        'Plrd' => 'ಪೊಲ್ಲಾರ್ಡ್ ಫೊನೆಟಿಕ್',
        'Prti' => 'ಇನ್ಸ್‌ಕ್ರಿಪ್ಶನಲ್ ಪಾರ್ಥಿಯನ್',
        'Rjng' => 'ರೆಜಾಂಗ್',
        'Roro' => 'ರೋಂಗೋರೋಂಗೋ',
        'Runr' => 'ರೂನಿಕ್',
        'Samr' => 'ಸಮಾರಿಟನ್',
        'Sara' => 'ಸರಾಟಿ',
        'Saur' => 'ಸೌರಾಷ್ಟ್ರ',
        'Sgnw' => 'ಸೈನ್‌ರೈಟಿಂಗ್',
        'Shaw' => 'ಶಾವಿಯಾನ್',
        'Sinh' => 'ಸಿಂಹಳ',
        'Sund' => 'ಸುಂಡಾನೀಸ್',
        'Sylo' => 'ಸೈಲೋಟಿ ನಗ್ರಿ',
        'Syrc' => 'ಸಿರಿಯಾಕ್',
        'Syre' => 'ಎಸ್ಟ್ರಾಂಜಿಲೋ ಸಿರಿಯಾಕ್',
        'Syrj' => 'ಪಶ್ಚಿಮ ಸಿರಿಯಾಕ್',
        'Syrn' => 'ಪೂರ್ವ ಸಿರಿಯಾಕ್',
        'Tagb' => 'ಟಾಗ್ಬಾನವಾ',
        'Tale' => 'ಥಾಯ್ ಲಿ',
        'Talu' => 'ನ್ಯೂ ಥಾಯ್ ಲುಇ',
        'Taml' => 'ತಮಿಳು',
        'Tavt' => 'ಥಾಯ್ ವಿಯೆಟ್',
        'Telu' => 'ತೆಲುಗು',
        'Teng' => 'ತೆಂಗ್‌ವಾರ್',
        'Tfng' => 'ಟಿಫಿನಾಘ್',
        'Tglg' => 'ಟ್ಯಾಗಲೋಗ್',
        'Thaa' => 'ಥಾನಾ',
        'Thai' => 'ಥಾಯ್',
        'Tibt' => 'ಟಿಬೇಟನ್',
        'Ugar' => 'ಉಗಾರಿಟಿಕ್',
        'Vaii' => 'ವಾಯ್',
        'Visp' => 'ವಿಸಿಬಲ್ ಸ್ಪೀಚ್',
        'Xpeo' => 'ಪ್ರಾಚೀನ ಪರ್ಶಿಯನ್',
        'Xsux' => 'ಸುಮೇರೋ-ಅಕ್ಕಾಡಿಯನ್ ಕ್ಯೂನಿಫಾರ್ಮ್',
        'Yiii' => 'ಯಿ',
        'Zinh' => 'ಇನ್‍ಹೆರಿಟೆಡ್',
        'Zmth' => 'ಗಣಿತ ಸಂಕೇತಲಿಪಿ',
        'Zsye' => 'ಎಮೋಜಿ',
        'Zsym' => 'ಸಂಕೇತಗಳು',
        'Zxxx' => 'ಅಲಿಖಿತ',
        'Zyyy' => 'ಸಾಮಾನ್ಯ',
    ],
];

==> symfony_5.4.23+dfsg.orig.tar.xz: symfony-5.4.23/src/Symfony/Component/Intl/Resources/data/scripts/kn.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'ಆ್ಯಡ್ಲಮ್',
        'Arab' => 'ಅರೇಬಿಕ್',
        'Aran' => 'ನಸ್ಟಾಲಿಕ್',
        'Armi' => 'ಇಂಪೀರಿಯಲ್ ಅರೆಮಾಯಿಕ್',
        'Armn' => 'ಅರ್ಮೇನಿಯನ್',
        'Avst' => 'ಅವೆಸ್ತಾನ್',
        'Bali' => 'ಬಾಲಿನೀಸ್',
        'Batk' => 'ಬಾಟಕ್',
        'Beng' => 'ಬೆಂಗಾಲಿ',
        'Blis' => 'ಬ್ಲಿಸ್‌ಸಿಂಬಲ್ಸ್',
        'Bopo' => 'ಬೋಪೊಮೋಫೋ',
        'Brah' => 'ಬ್ರಾಹ್ಮಿ',
        'Brai' => 'ಬ್ರೈಲ್',
        'Bugi' => 'ಬಗಿನೀಸ್',
        'Buhd' => 'ಬುಹಿದ್',
        'Cakm' => 'ಚಕ್ಮಾ',
        'Cans' => 'ಯುನಿಫೈಯ್ಡ್ ಕೆನೆಡಿಯನ್ ಅಬೊರಿಜಿನಲ್ ಸಿಲ್ಯಾಬಿಕ್ಸ್',
        'Cari' => 'ಕರೇನ್',
        'Cham' => 'ಚಾಮ್',
        'Cher' => 'ಚೆರೋಕೀ',
        'Cirt' => 'ಸಿರ್ಥ್',
        'Copt' => 'ಕಾಪ್ಟಿಕ್',
        'Cprt' => 'ಸಿಪ್ರಿಯಾಟ್',
        'Cyrl' => 'ಸಿರಿಲಿಕ್',
        'Cyrs' => 'ಪ್ರಾಚೀನ ಚರ್ಚ್ ಸ್ಲೋವಾನಿಕ್ ಸಿರಿಲಿಕ್',
        'Deva' => 'ದೇವನಾಗರಿ',
        'Dsrt' => 'ಡಸರ್ಟ್',
        'Egyd' => 'ಈಜಿಪ್ಟಿಯನ್ ಡೆಮೋಟಿಕ್',
        'Egyh' => 'ಈಜಿಪ್ಟಿಯನ್ ಹಯಾರಿಟಿಕ್',
        'Egyp' => 'ಈಜಿಪ್ಟಿಯನ್ ಹೀರೋಗ್ಲಿಫ್ಸ್',
        'Ethi' => 'ಇಥಿಯೋಪಿಕ್',
        'Geok' => 'ಜಾರ್ಜಿಯನ್ ಖುಸ್ತುರಿ',
        'Geor' => 'ಜಾರ್ಜಿಯನ್',
        'Glag' => 'ಗ್ಲಾಗೋಲಿಟಿಕ್',
        'Goth' => 'ಗೋತಿಕ್',
        'Grek' => 'ಗ್ರೀಕ್',
        'Gujr' => 'ಗುಜರಾತಿ',
        'Guru' => 'ಗುರ್ಮುಖಿ',
        'Hanb' => 'ಬೋಪೋಮೊಫೋ ಜೊತೆಗೆ ಹಾನ್',
        'Hang' => 'ಹ್ಯಾಂಗುಲ್',
        'Hani' => 'ಹಾನ್',
        'Hano' => 'ಹನೂನೂ',
        'Hans' => 'ಸರಳೀಕೃತ',
        'Hant' => 'ಸಾಂಪ್ರದಾಯಿಕ',
        'Hebr' => 'ಹೀಬ್ರೂ',
        'Hira' => 'ಹಿರಾಗನ',
        'Hmng' => 'ಪಹವ್ ಹ್ಮೋಂಗ್',
        'Hrkt' => 'ಜಪಾನೀಸ್ ಸಿಲಬರೀಸ್',
        'Hung' => 'ಪ್ರಾಚೀನ ಹಂಗೇರಿಯನ್',
        'Inds' => 'ಸಿಂಧೂ',
        'Ital' => 'ಪ್ರಾಚೀನ್ ಇಟಾಲಿಕ್',
        'Jamo' => 'ಜಮೋ',
        'Java' => 'ಜಾವನೀಸ್',
        'Jpan' => 'ಜಾಪನೀಸ್',
        'Kali' => 'ಕೆಯಾ ಲಿ',
        'Kana' => 'ಕಟಕಾನಾ',
        'Khar' => 'ಖರೋಶ್ತಿ',
        'Khmr' => 'ಖಮೇರ್',
        'Knda' => 'ಕನ್ನಡ',
        'Kore' => 'ಕೊರಿಯನ್',
        'Kthi' => 'ಕೈಥಿ',
        'Lana' => 'ಲಾನಾ',
        'Laoo' => 'ಲಾವೋ',
        'Latf' => 'ಫ್ರಾಕ್ತರ್ ಲ್ಯಾಟಿನ್',
        'Latg' => 'ಗೇಲಿಕ್ ಲ್ಯಾಟಿನ್',
        'Latn' => 'ಲ್ಯಾಟಿನ್',
        'Lepc' => 'ಲೆಪ್ಚಾ',
        'Limb' => 'ಲಿಂಬು',
        'Lina' => 'ಲೀನಯರ್ ಎ',
        'Linb' => 'ಲೀನಯರ್ ಬಿ',
        'Lyci' => 'ಲೈಸಿಯನ್',
        'Lydi' => 'ಲಿಡಿಯನ್',
        'Mand' => 'ಮಂಡೇಯನ್',
        'Mani' => 'ಮನಿಚೈಯನ್',
        'Maya' => 'ಮಯಾನ್ ಹೀರೋಗ್ಲಿಫ್ಸ್',
        'Mero' => 'ಮೆರೊಯಿಟಿಕ್',
        'Mlym' => 'ಮಲಯಾಳಂ',
        'Mong' => 'ಮಂಗೋಲಿಯನ್',
        'Moon' => 'ಮೂನ್',
        'Mtei' => 'ಮೈತಿ ಮಯೆಕ್',
        'Mymr' => 'ಮ್ಯಾನ್ಮಾರ್',
        'Nkoo' => 'ಎನ್‍ಕೋ',
        'Ogam' => 'ಓಘಮ್',
        'Olck' => 'ಓಲ್ ಚಿಕಿ',
        'Orkh' => 'ಓರ್ಖೋನ್',
        'Orya' => 'ಒಡಿಯಾ',
        'Osma' => 'ಓಸ್ಮಾನ್ಯಾ',
        'Perm' => 'ಪ್ರಾಚೀನ ಪೆರ್ಮಿಕ್',
        'Phag' => 'ಫಾಗ್ಸ್-ಪಾ',
        'Phli' => 'ಇನ್ಸ್‌ಕ್ರಿಪ್ಶನಲ್ ಪಾಹ್ಲವಿ',
        'Phlp' => 'ಸಾಲ್ಟರ್ ಪಾಹ್ಲವಿ',
        'Phlv' => 'ಬುಕ್ ಪಾಹ್ಲವಿ',
        'Phnx' => 'ಫೀನಿಶಿಯನ್',
        'Plrd' => 'ಪೊಲ್ಲಾರ್ಡ್ ಫೊನೆಟಿಕ್',
        'Prti' => 'ಇನ್ಸ್‌ಕ್ರಿಪ್ಶನಲ್ ಪಾರ್ಥಿಯನ್',
        'Rjng' => 'ರೆಜಾಂಗ್',
        'Rohg' => 'ಹನೀಫಿ',
        'Roro' => 'ರೋಂಗೋರೋಂಗೋ',
        'Runr' => 'ರೂನಿಕ್',
        'Samr' => 'ಸಮಾರಿಟನ್',
        'Sara' => 'ಸರಾಟಿ',
        'Saur' => 'ಸೌರಾಷ್ಟ್ರ',
        'Sgnw' => 'ಸೈನ್‌ರೈಟಿಂಗ್',
        'Shaw' => 'ಶಾವಿಯಾನ್',
        'Sinh' => 'ಸಿಂಹಳ',
        'Sund' => 'ಸುಂಡಾನೀಸ್',
        'Sylo' => 'ಸೈಲೋಟಿ ನಗ್ರಿ',
        'Syrc' => 'ಸಿರಿಯಾಕ್',
        'Syre' => 'ಎಸ್ಟ್ರಾಂಜಿಲೋ ಸಿರಿಯಾಕ್',
        'Syrj' => 'ಪಶ್ಚಿಮ ಸಿರಿಯಾಕ್',
        'Syrn' => 'ಪೂರ್ವ ಸಿರಿಯಾಕ್',
        'Tagb' => 'ಟಾಗ್ಬಾನವಾ',
        'Tale' => 'ಥಾಯ್ ಲಿ',
        'Talu' => 'ನ್ಯೂ ಥಾಯ್ ಲುಇ',
        'Taml' => 'ತಮಿಳು',
        'Tavt' => 'ಥಾಯ್ ವಿಯೆಟ್',
        'Telu' => 'ತೆಲುಗು',
        'Teng' => 'ತೆಂಗ್‌ವಾರ್',
        'Tfng' => 'ಟಿಫಿನಾಘ್',
        'Tglg' => 'ಟ್ಯಾಗಲೋಗ್',
        'Thaa' => 'ಥಾನಾ',
        'Thai' => 'ಥಾಯ್',
        'Tibt' => 'ಟಿಬೇಟನ್',
        'Ugar' => 'ಉಗಾರಿಟಿಕ್',
        'Vaii' => 'ವಾಯ್',
        'Visp' => 'ವಿಸಿಬಲ್ ಸ್ಪೀಚ್',
        'Xpeo' => 'ಪ್ರಾಚೀನ ಪರ್ಶಿಯನ್',
        'Xsux' => 'ಸುಮೇರೋ-ಅಕ್ಕಾಡಿಯನ್ ಕ್ಯೂನಿಫಾರ್ಮ್',
        'Yiii' => 'ಯಿ',
        'Zinh' => 'ಇನ್‍ಹೆರಿಟೆಡ್',
        'Zmth' => 'ಗಣಿತ ಸಂಕೇತಲಿಪಿ',
        'Zsye' => 'ಎಮೋಜಿ',
        'Zsym' => 'ಸಂಕೇತಗಳು',
        'Zxxx' => 'ಅಲಿಖಿತ',
        'Zyyy' => 'ಸಾಮಾನ್ಯ',
    ],
];
